@@ -19,9 +19,7 @@ DATA = {
         "formatString": "{name}-{version}-{release}.al.2017.03.{arch}.rpm"
     },
     "archlinux": {
-        # there is no official arch linux docker image, so users will have
-        # to specify one
-        "dockerImage": None,
+        "dockerImage": "archlinux:20200306",
         "packageType": "pkgbuild",
         "formatString": "{name}-{version}-{release}-{arch}.pkg.tar.xz"
     },
@@ -146,6 +144,11 @@ DATA = {
         "packageType": "rpm-dnf",
         "formatString": "{name}-{version}-{release}.fc32.{arch}.rpm"
     },
+    "opensuse.tumbleweed": {
+        "dockerImage": "opensuse/tumbleweed:latest",
+        "packageType": "rpm-zypper",
+        "formatString": "{name}-{version}-{release}.opensuse.tumbleweed.{arch}.rpm"
+    },
     "opensuse42.3": {
         "dockerImage": "opensuse/leap:42.3",
         "packageType": "rpm-zypper",
